mailr12636 - /branches/cst/maths_fns/mf.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 01, 2011 - 09:57:
Author: bugman
Date: Tue Mar  1 09:57:45 2011
New Revision: 12636

URL: http://svn.gna.org/viewcvs/relax?rev=12636&view=rev
Log:
This change is related to the task #6397 (https://gna.org/task/?6397)

kada _at_ chemi _dot_ muni _dot_ cz

https://mail.gna.org/public/relax-devel/2011-02/msg00088.html
https://gna.org/task/download.php?file_id=12598

This patch includes change in init_res_data function of class Mf in a file 
maths_fns/mf.py. The
function is split into init_interaction_data and init_spin_data. The 
initializations of
data.ri_prime, data.dri_prime, and data.d2ri_prime are excluded. Calls for 
both newly introduced
functions are incorporated in the patch.


Modified:
    branches/cst/maths_fns/mf.py

Modified: branches/cst/maths_fns/mf.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/cst/maths_fns/mf.py?rev=12636&r1=12635&r2=12636&view=diff
==============================================================================
--- branches/cst/maths_fns/mf.py (original)
+++ branches/cst/maths_fns/mf.py Tue Mar  1 09:57:45 2011
@@ -258,6 +258,9 @@
             # Append a list-like object for the spin specific data.
             self.data.append(Spin_object())
 
+            # Initialise the spin specific data.
+            self.init_spin_data(self.data[i], self.diff_data)
+
             # The ratio of gyromagnetic ratios.
             g_ratio = gh[i] / gx[i]
 
@@ -327,8 +330,8 @@
                 else:
                     self.data[i][j].total_num_params = 
self.data[i][j].num_params + self.diff_data.num_params
 
-                # Initialise the residue specific data.
-                self.init_res_data(self.data[i][j], self.diff_data)
+                # Initialise the interaction specific data.
+                self.init_interaction_data(self.data[i][j], self.diff_data)
 
                 # Setup the residue specific equations.
                 if not self.setup_equations(self.data[i][j]):
@@ -1334,8 +1337,8 @@
             diff_data.d2dz_dgamma2 = zeros(3, float64)
 
 
-    def init_res_data(self, data, diff_data):
-        """Function for the initialisation of the residue specific data."""
+    def init_interaction_data(self, data, diff_data):
+        """Function for the initialisation of the interaction specific 
data."""
 
         # Correlation times.
         data.ci = zeros(diff_data.num_indices, float64)
@@ -1448,10 +1451,8 @@
         data.dip_jw_comps_hess = zeros(data.num_ri, float64)
         data.csa_jw_comps_hess = zeros(data.num_ri, float64)
 
-        # Transformed relaxation values, gradients, and Hessians.
-        data.ri_prime = zeros((data.num_ri), float64)
-        data.dri_prime = zeros((data.total_num_params, data.num_ri), float64)
-        data.d2ri_prime = zeros((data.total_num_params, 
data.total_num_params, data.num_ri), float64)
+    def init_spin_data(self, data, diff_data):
+        """Function for the initialisation of the spin specific data."""
 
         # Data structures containing the Ri values.
         data.ri = zeros(data.num_ri, float64)




Related Messages


Powered by MHonArc, Updated Tue Mar 01 11:40:01 2011